# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SendSmtpEmailAttachment(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'url': 'str',
        'content': 'str',
        'name': 'str'
    }

    attribute_map = {
        'url': 'url',
        'content': 'content',
        'name': 'name'
    }

    def __init__(self, url=None, content=None, name=None):  # noqa: E501
        """SendSmtpEmailAttachment - a model defined in Swagger"""  # noqa: E501

        self._url = None
        self._content = None
        self._name = None
        self.discriminator = None

        if url is not None:
            self.url = url
        if content is not None:
            self.content = content
        if name is not None:
            self.name = name

    @property
    def url(self):
        """Gets the url of this SendSmtpEmailAttachment.  # noqa: E501

        Absolute url of the attachment (no local file).  # noqa: E501

        :return: The url of this SendSmtpEmailAttachment.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this SendSmtpEmailAttachment.

        Absolute url of the attachment (no local file).  # noqa: E501

        :param url: The url of this SendSmtpEmailAttachment.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def content(self):
        """Gets the content of this SendSmtpEmailAttachment.  # noqa: E501

        Base64 encoded chunk data of the attachment generated on the fly  # noqa: E501

        :return: The content of this SendSmtpEmailAttachment.  # noqa: E501
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this SendSmtpEmailAttachment.

        Base64 encoded chunk data of the attachment generated on the fly  # noqa: E501

        :param content: The content of this SendSmtpEmailAttachment.  # noqa: E501
        :type: str
        """
        if content is not None and not re.search('^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$', content):  # noqa: E501
            raise ValueError("Invalid value for `content`, must be a follow pattern or equal to `/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/`")  # noqa: E501

        self._content = content

    @property
    def name(self):
        """Gets the name of this SendSmtpEmailAttachment.  # noqa: E501

        Required if content is passed. Name of the attachment  # noqa: E501

        :return: The name of this SendSmtpEmailAttachment.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SendSmtpEmailAttachment.

        Required if content is passed. Name of the attachment  # noqa: E501

        :param name: The name of this SendSmtpEmailAttachment.  # noqa: E501
        :type: str
        """

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SendSmtpEmailAttachment):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
