# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SendSms(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'reference': 'str',
        'message_id': 'int',
        'sms_count': 'int',
        'used_credits': 'float',
        'remaining_credits': 'float'
    }

    attribute_map = {
        'reference': 'reference',
        'message_id': 'messageId',
        'sms_count': 'smsCount',
        'used_credits': 'usedCredits',
        'remaining_credits': 'remainingCredits'
    }

    def __init__(self, reference=None, message_id=None, sms_count=None, used_credits=None, remaining_credits=None):  # noqa: E501
        """SendSms - a model defined in Swagger"""  # noqa: E501

        self._reference = None
        self._message_id = None
        self._sms_count = None
        self._used_credits = None
        self._remaining_credits = None
        self.discriminator = None

        self.reference = reference
        self.message_id = message_id
        if sms_count is not None:
            self.sms_count = sms_count
        if used_credits is not None:
            self.used_credits = used_credits
        if remaining_credits is not None:
            self.remaining_credits = remaining_credits

    @property
    def reference(self):
        """Gets the reference of this SendSms.  # noqa: E501


        :return: The reference of this SendSms.  # noqa: E501
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this SendSms.


        :param reference: The reference of this SendSms.  # noqa: E501
        :type: str
        """
        if reference is None:
            raise ValueError("Invalid value for `reference`, must not be `None`")  # noqa: E501

        self._reference = reference

    @property
    def message_id(self):
        """Gets the message_id of this SendSms.  # noqa: E501


        :return: The message_id of this SendSms.  # noqa: E501
        :rtype: int
        """
        return self._message_id

    @message_id.setter
    def message_id(self, message_id):
        """Sets the message_id of this SendSms.


        :param message_id: The message_id of this SendSms.  # noqa: E501
        :type: int
        """
        if message_id is None:
            raise ValueError("Invalid value for `message_id`, must not be `None`")  # noqa: E501

        self._message_id = message_id

    @property
    def sms_count(self):
        """Gets the sms_count of this SendSms.  # noqa: E501

        Count of SMS's to send multiple text messages  # noqa: E501

        :return: The sms_count of this SendSms.  # noqa: E501
        :rtype: int
        """
        return self._sms_count

    @sms_count.setter
    def sms_count(self, sms_count):
        """Sets the sms_count of this SendSms.

        Count of SMS's to send multiple text messages  # noqa: E501

        :param sms_count: The sms_count of this SendSms.  # noqa: E501
        :type: int
        """

        self._sms_count = sms_count

    @property
    def used_credits(self):
        """Gets the used_credits of this SendSms.  # noqa: E501

        SMS credits used per text message  # noqa: E501

        :return: The used_credits of this SendSms.  # noqa: E501
        :rtype: float
        """
        return self._used_credits

    @used_credits.setter
    def used_credits(self, used_credits):
        """Sets the used_credits of this SendSms.

        SMS credits used per text message  # noqa: E501

        :param used_credits: The used_credits of this SendSms.  # noqa: E501
        :type: float
        """

        self._used_credits = used_credits

    @property
    def remaining_credits(self):
        """Gets the remaining_credits of this SendSms.  # noqa: E501

        Remaining SMS credits of the user  # noqa: E501

        :return: The remaining_credits of this SendSms.  # noqa: E501
        :rtype: float
        """
        return self._remaining_credits

    @remaining_credits.setter
    def remaining_credits(self, remaining_credits):
        """Sets the remaining_credits of this SendSms.

        Remaining SMS credits of the user  # noqa: E501

        :param remaining_credits: The remaining_credits of this SendSms.  # noqa: E501
        :type: float
        """

        self._remaining_credits = remaining_credits

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SendSms):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
