# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from sib_api_v3_sdk.models.get_extended_contact_details_statistics_clicked import GetExtendedContactDetailsStatisticsClicked  # noqa: F401,E501
from sib_api_v3_sdk.models.get_extended_contact_details_statistics_messages_sent import GetExtendedContactDetailsStatisticsMessagesSent  # noqa: F401,E501
from sib_api_v3_sdk.models.get_extended_contact_details_statistics_opened import GetExtendedContactDetailsStatisticsOpened  # noqa: F401,E501
from sib_api_v3_sdk.models.get_extended_contact_details_statistics_unsubscriptions import GetExtendedContactDetailsStatisticsUnsubscriptions  # noqa: F401,E501


class GetExtendedContactDetailsStatistics(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'messages_sent': 'list[GetExtendedContactDetailsStatisticsMessagesSent]',
        'hard_bounces': 'list[GetExtendedContactDetailsStatisticsMessagesSent]',
        'soft_bounces': 'list[GetExtendedContactDetailsStatisticsMessagesSent]',
        'complaints': 'list[GetExtendedContactDetailsStatisticsMessagesSent]',
        'unsubscriptions': 'GetExtendedContactDetailsStatisticsUnsubscriptions',
        'opened': 'list[GetExtendedContactDetailsStatisticsOpened]',
        'clicked': 'list[GetExtendedContactDetailsStatisticsClicked]',
        'transac_attributes': 'list[object]'
    }

    attribute_map = {
        'messages_sent': 'messagesSent',
        'hard_bounces': 'hardBounces',
        'soft_bounces': 'softBounces',
        'complaints': 'complaints',
        'unsubscriptions': 'unsubscriptions',
        'opened': 'opened',
        'clicked': 'clicked',
        'transac_attributes': 'transacAttributes'
    }

    def __init__(self, messages_sent=None, hard_bounces=None, soft_bounces=None, complaints=None, unsubscriptions=None, opened=None, clicked=None, transac_attributes=None):  # noqa: E501
        """GetExtendedContactDetailsStatistics - a model defined in Swagger"""  # noqa: E501

        self._messages_sent = None
        self._hard_bounces = None
        self._soft_bounces = None
        self._complaints = None
        self._unsubscriptions = None
        self._opened = None
        self._clicked = None
        self._transac_attributes = None
        self.discriminator = None

        if messages_sent is not None:
            self.messages_sent = messages_sent
        if hard_bounces is not None:
            self.hard_bounces = hard_bounces
        if soft_bounces is not None:
            self.soft_bounces = soft_bounces
        if complaints is not None:
            self.complaints = complaints
        if unsubscriptions is not None:
            self.unsubscriptions = unsubscriptions
        if opened is not None:
            self.opened = opened
        if clicked is not None:
            self.clicked = clicked
        if transac_attributes is not None:
            self.transac_attributes = transac_attributes

    @property
    def messages_sent(self):
        """Gets the messages_sent of this GetExtendedContactDetailsStatistics.  # noqa: E501

        Listing of the sent campaign for the contact  # noqa: E501

        :return: The messages_sent of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :rtype: list[GetExtendedContactDetailsStatisticsMessagesSent]
        """
        return self._messages_sent

    @messages_sent.setter
    def messages_sent(self, messages_sent):
        """Sets the messages_sent of this GetExtendedContactDetailsStatistics.

        Listing of the sent campaign for the contact  # noqa: E501

        :param messages_sent: The messages_sent of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :type: list[GetExtendedContactDetailsStatisticsMessagesSent]
        """

        self._messages_sent = messages_sent

    @property
    def hard_bounces(self):
        """Gets the hard_bounces of this GetExtendedContactDetailsStatistics.  # noqa: E501

        Listing of the hardbounes generated by the contact  # noqa: E501

        :return: The hard_bounces of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :rtype: list[GetExtendedContactDetailsStatisticsMessagesSent]
        """
        return self._hard_bounces

    @hard_bounces.setter
    def hard_bounces(self, hard_bounces):
        """Sets the hard_bounces of this GetExtendedContactDetailsStatistics.

        Listing of the hardbounes generated by the contact  # noqa: E501

        :param hard_bounces: The hard_bounces of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :type: list[GetExtendedContactDetailsStatisticsMessagesSent]
        """

        self._hard_bounces = hard_bounces

    @property
    def soft_bounces(self):
        """Gets the soft_bounces of this GetExtendedContactDetailsStatistics.  # noqa: E501

        Listing of the softbounes generated by the contact  # noqa: E501

        :return: The soft_bounces of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :rtype: list[GetExtendedContactDetailsStatisticsMessagesSent]
        """
        return self._soft_bounces

    @soft_bounces.setter
    def soft_bounces(self, soft_bounces):
        """Sets the soft_bounces of this GetExtendedContactDetailsStatistics.

        Listing of the softbounes generated by the contact  # noqa: E501

        :param soft_bounces: The soft_bounces of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :type: list[GetExtendedContactDetailsStatisticsMessagesSent]
        """

        self._soft_bounces = soft_bounces

    @property
    def complaints(self):
        """Gets the complaints of this GetExtendedContactDetailsStatistics.  # noqa: E501

        Listing of the complaints generated by the contact  # noqa: E501

        :return: The complaints of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :rtype: list[GetExtendedContactDetailsStatisticsMessagesSent]
        """
        return self._complaints

    @complaints.setter
    def complaints(self, complaints):
        """Sets the complaints of this GetExtendedContactDetailsStatistics.

        Listing of the complaints generated by the contact  # noqa: E501

        :param complaints: The complaints of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :type: list[GetExtendedContactDetailsStatisticsMessagesSent]
        """

        self._complaints = complaints

    @property
    def unsubscriptions(self):
        """Gets the unsubscriptions of this GetExtendedContactDetailsStatistics.  # noqa: E501


        :return: The unsubscriptions of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :rtype: GetExtendedContactDetailsStatisticsUnsubscriptions
        """
        return self._unsubscriptions

    @unsubscriptions.setter
    def unsubscriptions(self, unsubscriptions):
        """Sets the unsubscriptions of this GetExtendedContactDetailsStatistics.


        :param unsubscriptions: The unsubscriptions of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :type: GetExtendedContactDetailsStatisticsUnsubscriptions
        """

        self._unsubscriptions = unsubscriptions

    @property
    def opened(self):
        """Gets the opened of this GetExtendedContactDetailsStatistics.  # noqa: E501

        Listing of the openings generated by the contact  # noqa: E501

        :return: The opened of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :rtype: list[GetExtendedContactDetailsStatisticsOpened]
        """
        return self._opened

    @opened.setter
    def opened(self, opened):
        """Sets the opened of this GetExtendedContactDetailsStatistics.

        Listing of the openings generated by the contact  # noqa: E501

        :param opened: The opened of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :type: list[GetExtendedContactDetailsStatisticsOpened]
        """

        self._opened = opened

    @property
    def clicked(self):
        """Gets the clicked of this GetExtendedContactDetailsStatistics.  # noqa: E501

        Listing of the clicks generated by the contact  # noqa: E501

        :return: The clicked of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :rtype: list[GetExtendedContactDetailsStatisticsClicked]
        """
        return self._clicked

    @clicked.setter
    def clicked(self, clicked):
        """Sets the clicked of this GetExtendedContactDetailsStatistics.

        Listing of the clicks generated by the contact  # noqa: E501

        :param clicked: The clicked of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :type: list[GetExtendedContactDetailsStatisticsClicked]
        """

        self._clicked = clicked

    @property
    def transac_attributes(self):
        """Gets the transac_attributes of this GetExtendedContactDetailsStatistics.  # noqa: E501

        Listing of the transactional attributes for the contact  # noqa: E501

        :return: The transac_attributes of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :rtype: list[object]
        """
        return self._transac_attributes

    @transac_attributes.setter
    def transac_attributes(self, transac_attributes):
        """Sets the transac_attributes of this GetExtendedContactDetailsStatistics.

        Listing of the transactional attributes for the contact  # noqa: E501

        :param transac_attributes: The transac_attributes of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :type: list[object]
        """

        self._transac_attributes = transac_attributes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetExtendedContactDetailsStatistics):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
